# hj-check-os-version

## USE
```python
$ pip install hj-check-os-version
$ python
>>> from hj_check_os_version .hi import hi
>>> hi()
```

### Devlelopment environment Setting

```bash
$ install pdm
$ git clone
$ source .vnev/bin/activate
# $ vi ...

# TEST
$ pdm install
$ pdm test
$ pip install

$ git add <file-name>
$ git commit -a
$ git push
$ pdm publish 

